 Index of Dos Procedures and Functions (alphabetical)

This index is an alphabetical listing of the procedures and functions in the
Dos unit.

To look up Dos routines by functional category, see the
categorical index of Dos procedures and functions.

 DiskFree     Func  Returns the number of free bytes of the specified
                    disk drive.
 DiskSize     Func  Returns the total size, in bytes, of specified disk
                    drive.
 DosExitCode  Func  Returns the exit code of a subprocess.
 DosVersion   Func  Returns the DOS version number.
 EnvCount     Func  Returns the number of strings contained in the Dos
                    evironment.
 EnvStr       Func  Returns a specified environment string.
 Exec         Proc  Executes a specified program with a specified command
                    line.
 FExpand      Func  Expands a file name into a fully-qualified file name.
 FindFirst    Proc  Searches the specified directory for the matching
                    file.
 FindNext     Proc  Searches for another FindFirst file.
 FSearch      Func  Searches for a file.
 FSplit       Func  Splits a file name into its three components.
 GetCBreak    Proc  Returns the state of Ctrl-Break checking in DOS.
 GetDate      Proc  Returns the current date set in the operating system.
 GetEnv       Func  Returns the value of a specified environment variable.
 GetFAttr     Proc  Returns the attributes of a file.
 GetFTime     Proc  Returns the date and time a file was last written.
 GetIntVec    Proc  Returns the address stored in a specified interrupt
                    vector.
 GetTime      Proc  Returns the current time set in the operating system.
 GetVerify    Proc  Returns the state of the verify flag in DOS.
 Intr         Proc  Executes a specified software interrupt.
 Keep         Proc  Keep (or Terminate Stay Resident) terminates the
                    program and makes it stay in memory.
 MsDos        Proc  Executes a DOS function call.
 PackTime     Proc  Converts a TDateTime record.
 SetCBreak    Proc  Sets the state of Ctrl-Break checking in DOS.
 SetDate      Proc  Sets the current date in the operating system.
 SetFAttr     Proc  Sets the attributes of a file.
 SetFTime     Proc  Sets the date and time a file was last written.
 SetIntVec    Proc  Sets a specified interrupt vector to a specified
                    address.
 SetTime      Proc  Sets the current time in the operating system.
 SetVerify    Proc  Sets the state of the verify flag in DOS.
 SwapVectors  Proc  Swaps the SaveIntXX pointers in the System unit with
                    the current vectors.
 UnpackTime   Proc  Converts a Longint to a record.


FUNZIONI DOS


--- Exec (procedure)     (Dos unit)

Executes a specified program with a specified command line.

 Declaration:
 procedure  Exec(Path, CmdLine: string);

 Target:
Real, Protected

 Remarks:
Errors are reported in DosError. When compiling a program that uses Exec,
reduce the "maximum" heap size; otherwise, there won't be enough memory
(DosError = 8).


 Sample Code:

  {DOSXCODE.PAS}

 { Example for DosExitCode and Exec }

 {$M $4000,0,0 }   { 16K stack, no heap }
 uses Dos;
 var
   ProgramName, CmdLine: string;
 begin
   Write('Program to Exec (full path): ');
   ReadLn(ProgramName);
   Write('Command line to pass to ',
         ProgramName, ': ');
   ReadLn(CmdLine);
   WriteLn('About to Exec...');
   SwapVectors;
   Exec(ProgramName, CmdLine);
   SwapVectors;
   WriteLn('...back from Exec');
   if DosError <> 0 then{ Error? }
     WriteLn('Dos error #', DosError)
   else
     WriteLn('Exec successful. ',
             'Child process exit code = ',
             DosExitCode);
 end.



--- FExpand (function)     (Dos unit)

Expands a file name into a fully-qualified file name.

 Declaration:
 function FExpand (Path: PathStr): PathStr;

 Target:
Real, Protected

 Remarks:
The PathStr type is defined in the Dos unit.


 Sample Code:

  {FExpand.PAS}

 { Example for FExpand and FSearch }

 uses Dos;
 var
   S: PathStr;
 begin
   S := FSearch('TURBO.EXE',GetEnv('PATH'));
   if S = '' then
     WriteLn('TURBO.EXE not found')
   else
     { Show full path }
     WriteLn('Found as ',FExpand(S));
 end.


--- FindFirst (procedure)     (Dos unit )

Searches the specified directory for the matching file.

 Declaration:
 procedure FindFirst(Path: PChar; Attr: Word; var F: TSearchRec);

 Target:
Real, Protected

 Remarks:
Searches the specified (or current) directory for the first entry matching
the specified file name and set of attributes.


 Sample Code:

 {Findfrst.PAS}

 {Sample code for the FindFirst and FindNext procedures.}


 uses Dos;

 var
  DirInfo: SearchRec;
 begin
  FindFirst('*.PAS', Archive, DirInfo); { Same as DIR *.PAS }
  while DosError = 0 do
  begin
    Writeln(DirInfo.Name);
    FindNext(DirInfo);
  end;
 end.


---  FindNext (procedure)     (Dos unit)

Finds the next entry that matches the name and attributes specified in an
earlier call to FindFirst.

 Declaration:
 procedure FindNext(var F: TSearchRec);

 Target:
Windows, Real, Protected

 Remarks:
Errors are reported in DosError. The only possible error code is 18 (no more
files).


 Sample Code:

 {Findfrst.PAS}

 {Sample code for the FindFirst and FindNext procedures.}


 uses Dos;

 var
  DirInfo: SearchRec;
 begin
  FindFirst('*.PAS', Archive, DirInfo); { Same as DIR *.PAS }
  while DosError = 0 do
  begin
    Writeln(DirInfo.Name);
    FindNext(DirInfo);
  end;
 end.







--- FSearch (function)     (Dos unit)

Searches for a file.

 Declaration:
 function FSearch(Path: PathStr; DirList: string): PathStr;

 Target:
Real, Protected

 Remarks:
Searches in a list of directories (DirList). The directories in DirList must
be separated by semicolons. The PathStr type is defined in the Dos unit.

 See Also:
 FExpand
 FSplit
 GetEnv

 Sample Code:

  {FExpand.PAS}

 { Example for FExpand and FSearch }

 uses Dos;
 var
   S: PathStr;
 begin
   S := FSearch('TURBO.EXE',GetEnv('PATH'));
   if S = '' then
     WriteLn('TURBO.EXE not found')
   else
     { Show full path }
     WriteLn('Found as ',FExpand(S));
 end.




